Structs
Functions
- get_
trace_ cache - Get access to the current TraceCache
- get_
trace_ summary_ service - Retrieve the global TraceSummaryService (if initialized).
- init_
trace_ cache - Initialize the TraceCache, replacing any previous instance. The old background flush task is signaled to stop and any remaining traces are flushed with the NEW pool before the cache is swapped.
- init_
trace_ summary_ service - Register the global TraceSummaryService. Replaces any previously registered instance.
- shutdown_
trace_ cache - Flush all remaining traces during shutdown