Structs
Functions
- get_
trace_ cache - Get access to the current TraceCache
- init_
trace_ cache - Initialize the TraceCache, replacing any previous instance. The old background flush task is signaled to stop and any remaining traces are flushed with the NEW pool before the cache is swapped.
- shutdown_
trace_ cache - Flush all remaining traces during shutdown